<?php
namespace Teknisa\CUS\Modules\Relatorio\Controllers;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class Cus02100AnaliseDeCusto extends \Zeedhi\Framework\Controller\Report {
  protected $novoCodigo;
  protected $consplan;
  protected $servicoPorGrupo;
  protected $nrorg;
  protected $cdfilial;
  protected $nrConsPlan;
  protected $birtStrategy;
  protected $Listas;
  protected $environment;
  protected $connection;

  public function __construct($reportService, $novoCodigo, $consplan, $servicoPorGrupo, $birtStrategy, $Listas, $environment, $util, StoredProcedure $procedureConsplanGeral, $connection) {
    $this->novoCodigo                 = $novoCodigo;
    $this->consplan                   = $consplan;
    $this->servicoPorGrupo            = $servicoPorGrupo;
    $this->reportService              = $reportService;
    $this->birtStrategy               = $birtStrategy;
    $this->Listas                     = $Listas;
    $this->environment                = $environment;
    $this->util                       = $util;
    $this->procedureConsplanGeral     = $procedureConsplanGeral;
    $this->connection                 = $connection;
  } 
  
  protected $reportMapping = array (
    'CUS02100' => 
    array (
      'strategy' => 'BIRT',
      'parameterMapping' => 
      array (
        'NRORG'       => 'P_NRORG',
        "CDFILIAL"    => "P_CDFILIAL",
        "CDSERVFILI"  => "P_CDSERVFILI",
        "DTINICIAL"   => "P_DTINIC",
        "DTFINAL"     => "P_DTFINA",
        "DTCUSTPADR"  => "P_DTCUSTPADR",
        "CDTIPOCUSTO" => "P_NRTIPOCUSTO",
        "CDGRUPPROD"  => "P_CDSUBGRPROD"
      )
    ),
    'CUS02101' => 
    array (
      'strategy' => 'BIRT',
      'parameterMapping' => 
      array (
        'NRORG'       => 'P_NRORG',
        "CDFILIAL"    => "P_CDFILIAL",
        "CDSERVFILI"  => "P_CDSERVFILI",
        "DTINICIAL"   => "P_DTINIC",
        "DTFINAL"     => "P_DTFINA",
        "DTCUSTPADR"  => "P_DTCUSTPADR",
        "CDTIPOCUSTO" => "P_NRTIPOCUSTO",
        "CDGRUPPROD"  => "P_CDSUBGRPROD",
        "NRCONSPLAN"  => "P_NRCONSPLAN"
      )
    )
  );
  
  public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
    $row = $request->getRow();
    $row['NRORG'] = $this->environment->getNrorg();
    $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
    
    if($row['CD_REPORT_NAME'] == 'CUS02101') {
      $nrConsPlan = $this->novoCodigo->getCodeByTableName('CONSPLAN'.$row['CDFILIAL'], $row['NRORG']);
      $cdOperador = $this->environment->getCdOperador();
      
      $row['NRCONSPLAN'] = $nrConsPlan;
      
      $procedureConsumoPlanejado = new StoredProcedure($this->connection, 'CONSUMO_PLANEJADO_PLA');
      $procedureConsumoPlanejado->addParam(new Param('P_FILIAL',       Param::PARAM_INPUT, $row['CDFILIAL'],   Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_SERVICOS',     Param::PARAM_INPUT, 'T',                Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_DTINICIAL',    Param::PARAM_INPUT, $row['DTINICIAL'],  Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_DTFINAL',      Param::PARAM_INPUT, $row['DTFINAL'],    Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_IDARQUIVO',    Param::PARAM_INPUT, 'C',                Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_IDPRODUTOS',   Param::PARAM_INPUT, 'CFP',              Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_IDSEPPRATO',   Param::PARAM_INPUT, 'P',                Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_PEACRESCIMO',  Param::PARAM_INPUT, 0,                  Param::PARAM_TYPE_INT));
      $procedureConsumoPlanejado->addParam(new Param('P_IDARREDOND',   Param::PARAM_INPUT, 'N',                Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_NRCONSPLAN',   Param::PARAM_INPUT, $nrConsPlan,        Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_CDPRODUTOINI', Param::PARAM_INPUT, ' ',                 Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_CDPRODUTOFIN', Param::PARAM_INPUT, 'zzzzzzzzzz',       Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_CDOPERADOR',   Param::PARAM_INPUT, $cdOperador,        Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_STDTINICIAL',  Param::PARAM_INPUT, null,               Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->addParam(new Param('P_STDTFINAL',    Param::PARAM_INPUT, null,               Param::PARAM_TYPE_STR));
      $procedureConsumoPlanejado->execute(); 
    }
  }
  
}